@@ -1,15 +1,15 @@
 
 context("Git")
 
-test_that("git_extract_sha1", {
+test_that("git_extract_sha1_tar", {
 
   skip_on_cran()
   skip_if_offline()
   skip_if_over_rate_limit()
 
   sha <- "fbae60ced0afee0e7c0f8dc3b5b1bb48d303f3dd"
-  url <- paste0(
-    "https://api.github.com/repos/hadley/devtools/zipball/",
+  url <- build_url(
+    "api.github.com/repos/hadley/devtools/tarball",
     sha
   )
 
@@ -18,7 +18,7 @@ test_that("git_extract_sha1", {
   download(tmp, url, auth_token = github_pat())
 
   expect_equal(
-    git_extract_sha1(tmp),
+    git_extract_sha1_tar(tmp),
     sha
   )
 })
